@@ -7,6 +7,9 @@ set_envvar <- function(envs, action = "replace") {
   stopifnot(is.character(action), length(action) == 1)
   action <- match.arg(action, c("replace", "prefix", "suffix"))
 
+  # if any envs are null make them NA instead
+  envs[vlapply(envs, is.null)] <- NA
+
   # if there are duplicated entries keep only the last one
   envs <- envs[!duplicated(names(envs), fromLast = TRUE)]
 
@@ -33,16 +36,24 @@ set_envvar <- function(envs, action = "replace") {
 #' Temporarily change system environment variables.
 #'
 #' @template with
-#' @param new `[named character]`\cr New environment variables
+#' @param new,.new `[named character]`\cr New environment variables
+#' @param ... Named arguments with new environment variables.
 #' @param action should new values `"replace"`, `"prefix"` or
 #'   `"suffix"` existing variables with the same name.
 #' @inheritParams with_collate
 #' @details if `NA` is used those environment variables will be unset.
 #' If there are any duplicated variable names only the last one is used.
 #' @seealso [Sys.setenv()]
+#' @examples
+#' with_envvar(new = c("GITHUB_PAT" = "abcdef"), Sys.getenv("GITHUB_PAT"))
+#'
+#' # with_envvar unsets variables after usage
+#' Sys.getenv("TEMP_SECRET")
+#' with_envvar(new = c("TEMP_SECRET" = "secret"), Sys.getenv("TEMP_SECRET"))
+#' Sys.getenv("TEMP_SECRET")
 #' @export
 with_envvar <- with_(set_envvar)
 
 #' @rdname with_envvar
 #' @export
-local_envvar <- local_(set_envvar)
+local_envvar <- local_(set_envvar, dots = TRUE)
