@@ -1,40 +1,3 @@
-context("local")
-
-test_that("local_envvar sets and unsets variables", {
-
-  # Make sure the "set_env_testvar" environment var is not set.
-  Sys.unsetenv("set_env_testvar")
-  expect_false("set_env_testvar" %in% names(Sys.getenv()))
-
-  # Use local_envvar (which calls set_envvar) to temporarily set it to 1
-  local({
-    local_envvar(c("set_env_testvar" = 1))
-    expect_identical("1", Sys.getenv("set_env_testvar"))
-  })
-
-  # set_env_testvar shouldn't stay in the list of environment vars
-  expect_false("set_env_testvar" %in% names(Sys.getenv()))
-})
-
-test_that("local_envar respects suffix and prefix", {
-  nested <- function(op1, op2) {
-    local({
-      local_envvar(c(A = 1), action = op1)
-      local({
-        local_envvar(c(A = 2), action = op2)
-        Sys.getenv("A")[[1]]
-      })
-    })
-  }
-
-  expect_equal(nested("replace", "suffix"), c("1 2"))
-  expect_equal(nested("replace", "prefix"), c("2 1"))
-  expect_equal(nested("prefix", "suffix"), c("1 2"))
-  expect_equal(nested("prefix", "prefix"), c("2 1"))
-  expect_equal(nested("suffix", "suffix"), c("1 2"))
-  expect_equal(nested("suffix", "prefix"), c("2 1"))
-})
-
 test_that("local_options works", {
   expect_false(getOption("scipen") == 999)
   local({
@@ -217,6 +180,19 @@ test_that("local_makevars works with alternative assignments", {
   expect_equal("CFLAGS=-03", readLines(current))
 })
 
+test_that("local_makevars uses the existing R_MAKEVARS_USER by default", {
+  tf <- tempfile()
+  local_envvar("R_MAKEVARS_USER" = tf)
+  on.exit(unlink(tf))
+  writeLines(con = tf, c("CFLAGS=-O3", "CXXFLAGS=-O3"), sep = "\n")
+  new <- c(CFLAGS = "-O0")
+  local({
+    local_makevars(new)
+    expect_equal(readLines(Sys.getenv("R_MAKEVARS_USER")), c("CFLAGS=-O0", "CXXFLAGS=-O3"))
+  })
+  expect_equal(readLines(tf), c("CFLAGS=-O3", "CXXFLAGS=-O3"))
+})
+
 test_that("local_dir works as expected", {
   old <- normalizePath(getwd())
   local({
